@@ -443,6 +443,8 @@ class Nested(Field):
         schema = self.schema
         if nested_obj is None:
             return None
+        if self.many and utils.is_iterable_but_not_string(nested_obj):
+            nested_obj = list(nested_obj)
         if not self.__updated_fields:
             schema._update_fields(obj=nested_obj, many=self.many)
             self.__updated_fields = True
@@ -827,6 +829,8 @@ class FormattedString(Field):
     _CHECK_ATTRIBUTE = False
 
     def __init__(self, src_str, *args, **kwargs):
+        warnings.warn('FormattedString is deprecated and will be removed in marshmallow 3. '
+                      'Use a Method or Function field instead.', RemovedInMarshmallow3Warning)
         Field.__init__(self, *args, **kwargs)
         self.src_str = text_type(src_str)
 
